@@ -3,14 +3,16 @@ function(
          dir="C:/myfiles/mymodels/myrun/",
          masterctlfile="control.ss_new",
          newctlfile="control_modified.ss", # must match entry in starter file
-         linenum=NULL, string=NULL, profilevec=NULL,
-         command="SS3 -nox",model='ss3',systemcmd=F,saveoutput=T,
-         verbose=T)
+         linenum=NULL, string=NULL, profilevec=NULL, usepar=TRUE,
+         dircopy=TRUE, exe.delete=FALSE,
+         command="SS3 -nox",model='ss3',systemcmd=FALSE,saveoutput=TRUE,
+         overwrite=FALSE,
+         verbose=TRUE)
 {
   ################################################################################
   #
   # SS_profile
-  # October 5, 2009.
+  # July 5, 2011.
   # This function comes with no warranty or guarantee of accuracy
   #
   # Purpose: run a likelihood profile by iteratively modifying
@@ -23,12 +25,12 @@ function(
   #
   ################################################################################
 
-  if(.Platform$OS.type=="windows") win <- T  else  win <- F
+  OS <- "Mac" # don't know the version$os info for Mac
+  if(length(grep("linux",version$os)) > 0) OS <- "Linux"
+  if(length(grep("mingw",version$os)) > 0) OS <- "Windows"
 
-  if(length(linenum)+length(string)!=1){
-    print("one value should be input for either 'linenum' or 'string', but not both",quote=F)
-    return()
-  }
+  if(length(linenum)+length(string)!=1)
+    stop("one value should be input for either 'linenum' or 'string', but not both")
   n <- length(profilevec)
   converged <- rep(NA,n)
   totallike <- rep(NA,n)
@@ -37,37 +39,50 @@ function(
   setwd(dir) # change working directory
   stdfile <- paste(model,'.std',sep='')
 
+  # read starter file to get input file names and check for prior in likelihood
+  starter.file <- dir()[tolower(dir())=='starter.ss']
+  if(length(starter.file)==0) stop("starter.ss not found in",dir)
+  starter <- SS_readstarter(starter.file)
+  if(starter$prior_like==0){
+    stop("for likelihood profile, you should change\n",
+         " 'Include prior likelihood for non-estimated parameters'\n",
+         " from 0 to 1 and re-run the estimation.\n")
+  }
+  
+
   # run loop over profile values
   for(i in 1:n){
     SS_changepars(dir=dir,ctlfile=masterctlfile,newctlfile=newctlfile,
-                  linenums=linenum,string=string,
-                  newvals=profilevec[i], estimate=F,
-                  verbose=T)
+                  linenums=linenum,strings=string,
+                  newvals=profilevec[i], estimate=FALSE,
+                  verbose=TRUE)
     if(file.exists(stdfile)) file.remove(stdfile)
     if(file.exists('Report.sso')) file.remove('Report.sso')
 
     # run model
-    if(win & !systemcmd){
+    cat("Running model in directory:",getwd(),"\n")
+    cat("Using the command:",command,"\n")
+    if(OS=="Windows" & !systemcmd){
       shell(cmd=command)
     }else{
       system(command)
     }
 
     converged[i] <- file.exists(stdfile)
-    onegood <- F
+    onegood <- FALSE
     if(file.exists('Report.sso') & file.info('Report.sso')$size>0){
-      onegood <- T
+      onegood <- TRUE
       Rep <- readLines('Report.sso',n=120)
-      like <- read.table('Report.sso',skip=grep('LIKELIHOOD',Rep)[2]+0,nrows=11,head=T,fill=T)
+      like <- read.table('Report.sso',skip=grep('LIKELIHOOD',Rep)[2]+0,nrows=11,header=TRUE,fill=TRUE)
       liketable <- rbind(liketable,as.numeric(like$logL.Lambda))
     }else{
       liketable <- rbind(liketable,rep(NA,10))
     }
 
     if(saveoutput){
-      file.copy('Report.sso',paste('Report',i,".sso",sep=""))
-      file.copy('CompReport.sso',paste('CompReport',i,".sso",sep=""))
-      file.copy('covar.sso',paste('covar',i,".sso",sep=""))
+      file.copy('Report.sso',paste('Report',i,".sso",sep=""),overwrite=overwrite)
+      file.copy('CompReport.sso',paste('CompReport',i,".sso",sep=""),overwrite=overwrite)
+      file.copy('covar.sso',paste('covar',i,".sso",sep=""),overwrite=overwrite)
     }
   } # end loop
   if(onegood){
@@ -77,8 +92,7 @@ function(
     names(bigtable)[1] <- 'Value'
     return(bigtable)
   }else{
-    print('Error: no good Report.sso files created in profile',quote=F)
-    return()
+    stop('Error: no good Report.sso files created in profile')
   }
 } # end function
 
