@@ -8,12 +8,17 @@ SSplotDiscard <-
            "Total discards",
            "for"),
            yhi=1,
+           col1="blue", col2="red",
            pwidth=7,pheight=7,punits="in",res=300,ptsize=12,cex.main=1,
            verbose=TRUE)
 {
-  # updated March 29, 2011
-
-  pngfun <- function(file) png(file=file,width=pwidth,height=pheight,units=punits,res=res,pointsize=ptsize)
+  pngfun <- function(file,caption=NA){
+    png(filename=file,width=pwidth,height=pheight,
+        units=punits,res=res,pointsize=ptsize)
+    plotinfo <- rbind(plotinfo,data.frame(file=file,caption=caption))
+    return(plotinfo)
+  }
+  plotinfo <- NULL
 
   # get stuff from replist
   discard         <- replist$discard
@@ -25,7 +30,7 @@ SSplotDiscard <-
   if(plotdir=="default") plotdir <- replist$inputs$dir
 
   # if discards exist
-  if(length(discard)>1){
+  if(!is.na(discard) && nrow(discard)>0){
     for(fleet in unique(discard$Fleet)){
       FleetNum <- as.numeric(strsplit(fleet,"_")[[1]][1])
       FleetName <- substring(fleet,nchar(FleetNum)+2)
@@ -89,19 +94,23 @@ SSplotDiscard <-
         }
       }
       dfracfunc <- function(){
-        plotCI(x=yr,y=ob,z=0,uiw=uiw,liw=liw,ylab=ylab,xlab=labels[1],main=title,ylo=0,yhi=yhi,col="red",sfrac=0.001,lty=1,xlim=xlim,ymax=max(usedisc$Exp,na.rm=TRUE))
+        plotCI(x=yr,y=ob,uiw=uiw,liw=liw,ylab=ylab,xlab=labels[1],main=title,
+               ylo=0,yhi=yhi,col=col2,sfrac=0.001,lty=1,xlim=xlim,
+               ymax=max(usedisc$Exp,na.rm=TRUE))
         abline(h=0,col="grey")
-        points(yr,usedisc$Exp,col="blue",pch="-",cex=2)
+        points(yr,usedisc$Exp,col=col1,pch="-",cex=2)
       }
       if(plot) dfracfunc()
       if(print) {
-        pngfun(file=paste(plotdir,"discfracfit",FleetName,".png",sep=""))
+        file <- paste(plotdir,"discfracfit",FleetName,".png",sep="")
+        caption <- title
+        plotinfo <- pngfun(file=file, caption=caption)
         dfracfunc()
         dev.off()
       }
     } # discard series
-    if(verbose) cat("Finished discard plot\n")
-  }else{ # if discards
-    if(verbose) cat("No discard data to plot\n")
+    #if(verbose) cat("Finished discard plot\n")
   }
+  if(!is.null(plotinfo)) plotinfo$category <- "Discard"
+  return(invisible(plotinfo))
 } # end of function
