@@ -10,7 +10,13 @@ SSplotSpawnrecruit <-
 {
   # plot of spawner recruit curve
 
-  pngfun <- function(file) png(file=file,width=pwidth,height=pheight,units=punits,res=res,pointsize=ptsize)
+  pngfun <- function(file,caption=NA){
+    png(filename=file,width=pwidth,height=pheight,
+        units=punits,res=res,pointsize=ptsize)
+    plotinfo <- rbind(plotinfo,data.frame(file=file,caption=caption))
+    return(plotinfo)
+  }
+  plotinfo <- NULL
 
   recruit <- replist$recruit
 
@@ -55,15 +61,20 @@ SSplotSpawnrecruit <-
   }    
   if(print){
     if(1 %in% subplot){
-      pngfun(file=paste(plotdir,"/SR_curve.png",sep=""))
+      file <- paste(plotdir,"/SR_curve.png",sep="")
+      caption <- "Spawner-recruit curve"
+      plotinfo <- pngfun(file=file, caption=caption)
       recruitfun()
       dev.off()
     }
     if(2 %in% subplot){
-      pngfun(file=paste(plotdir,"/SR_curve2.png",sep=""))
+      file <- paste(plotdir,"/SR_curve2.png",sep="")
+      caption <- paste("Spawner-recruit curve with labels on first, last, and years with (log) deviations >",textmindev)
+      plotinfo <- pngfun(file=file, caption=caption)
       recruitfun(text=TRUE)
       dev.off()
     }
   }
-  if(verbose) cat("Finished plot 12: Spawner-recruit curve\n")
+  if(!is.null(plotinfo)) plotinfo$category <- "S-R"
+  return(invisible(plotinfo))
 }
